JSONResultTracker
=================

.. currentmodule:: pykeen.trackers

.. autoclass:: JSONResultTracker
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~JSONResultTracker.extension

   .. rubric:: Methods Summary

   .. autosummary::

      ~JSONResultTracker.log_metrics
      ~JSONResultTracker.log_params

   .. rubric:: Attributes Documentation

   .. autoattribute:: extension

   .. rubric:: Methods Documentation

   .. automethod:: log_metrics
   .. automethod:: log_params
